OC.L10N.register(
    "photos",
    {
    "Photos" : "תמונות",
    "Your memories under your control" : "הזכרונות שלך בשליטתך",
    "Videos" : "סרטונים",
    "Folders" : "תיקייה",
    "Favorites" : "מועדפים",
    "Shared with you" : "משותף אתך",
    "Tags" : "תגיות",
    "Locations" : "מיקומים",
    "Back" : "חזרה",
    "Save" : "שמירה",
    "Open the full size \"{name}\" image" : "לפתוח את התמונה „{name}” בגודל מלא",
    "Open the \"{name}\" sub-directory" : "לפתוח את תת־התיקייה „{name}”",
    "Back to {folder}" : "חזרה אל {folder}",
    "Share this folder" : "שיתוף התיקייה הזו",
    "Enable squared photos view" : "הפעלת תצוגת תמונות מרובעות",
    "View" : "צפייה",
    "An error occurred" : "אירעה שגיאה",
    "Favorite" : "סימון כמועדף",
    "Remove from favorites" : "הסרה מהמועדפים",
    "No photos in here" : "אין כאן תמונות",
    "No tags yet" : "אין תגיות עדיין",
    "Photos with tags will show up here" : "תמונות עם תגיות תמיד תופענה כאן",
    "Add" : "הוספה",
    "Download" : "הורדה",
    "Delete selection" : "מחיקת בחירה",
    "Delete" : "מחיקה",
    "Tagged photos" : "תמונות מתויגות",
    "Your photos" : "התמונות שלך",
    "Your videos" : "הסרטונים שלך",
    "Your folders" : "התיקיות שלך",
    "Settings" : "הגדרות"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
